*
* Copyright (c) 1995,2000 by hartmut Goebel <hartmut@goebel.noris.de>
*
* $Id: $
*
**********************************************************************
*
*   d-ergo.asm - german ergonomic key map according to H. Meier
*
**********************************************************************
*
*------ Key Translation Table ----------------------------------------
*  Raw key codes
*
*   1   59 60 61 62 63   64 65 66 67 68 87 88     101  70 119
*  41   02 03 04 05 06 07 08 09 10 11 12 13   14  110 102 104  69  98  55  74
*  15    16 17 18 19 20 21 22 23 24 25 26 27  28  111 107 109  71  72  73    
*     58  30 31 32 33 34 35 36 37 38 39 40 43         103      75  76  77  78  
*  ..   86 44 45 46 47 48 49 50 51 52 53     54   105 108 106  79  80  81    
*  29 125 56              57       100 126 127 97             82      83  96 
*
*---------------------------------------------------------------------
*  German ergonomic (d-ergo) mapping
*
*  ESC  F1  F2  F3  F4  F5   F6  F7  F8  F9  F10
*  `~   1! 2" 3$ 4$ 5% 6& 7/ 8( 9) 0= ? '` \| BS  DEL HELP  [{  ]}  /  *
*  TAB   xX qQ hH wW zZ yY dD tT bB pP jJ +*  RET            7   8   9   -
*     CL  uU iI aA eE oO lL rR nN sS fF vF #^        UC      4  5  6  +
*  SH   <>    cC kK gG mM ,; .: -_     SH   LC DC RC   1  2  3  ENT
*  CT WIN ALT           SPACE       AGR WIN MEN CT           0      .
*
*
*  `~    @ #  % ^ & * ( )  dd \| BS  DEL HELP  [{  ]}  /  *
*  TAB       d`      [{ ]}  RET            7   8   9   -
*  CT CL            '" #^                4  4  5  +
*  SH      d  d^ d~ d ,< > /?     SH              1  2  3  ENT
*     ALT AM              SPACE            AM ALT            0      .
*
*---------------------------------------------------------------------
*  For comparison, here's German (D) mapping
*
*  ESC  F1  F2  F3  F4  F5   F6  F7  F8  F9  F10
*  `~   1! 2" 3 4$ 5% 6& 7/ 8( 9) 0= ? '` \| BS  DEL HELP  [{  ]}  /   *
*  TAB   qQ wW eE rR tT zZ uU iI oO pP  +*  RET            7   8   9   -
*  CT CL  aA sS dD fF gG hH jJ kK lL   #^        UC      4   5   6   +
*  SH <>   yY xX cC vV bB nN mM ,; .: -_     SH   LC DC RC   1   2   3   ENT
*     ALT AM              SPACE            AM ALT            0       .
*
*---------------------------------------------------------------------
*
* Order for modifiable keys
*    '`^~" single dead
*   ''^''' last recent is '
*   `^```` last recent is `
*


KMLCapsable: ; NL means NULL (undefined) and RE means RESERVED
        DC.B    %00000000       ; 7\ 6& 5% 4$ 3 2" 1! `~  07 - 00
        DC.B    %00000000       ; 0N NL \| '` ? 0= 9) 8(  0F - 08
        DC.B    %11111111       ; tT dD cC zZ wW hH qQ xX  17 - 10
        DC.B    %00000111       ; 3 2 1 NL +* jJ pP bB  1F - 18
        DC.B    %11111111       ; nN rR lL oO eE aA iI uU  27 - 20
        DC.B    %00000111       ; 6 5 4 NL #' vF fF sS  2F - 28
        DC.B    %11111110       ; mM gG kK yY    <>  37 - 30
        DC.B    %00000000       ; 9  8  7  . NL -_ .: ,;  3F - 38
KMHCapsable:
        DC.B    %00000000       ; 47 - 40
        DC.B    %00000000       ; 4F - 48
        DC.B    %00000000       ; 57 - 50
        DC.B    %00000000       ; 5F - 58
        DC.B    %00000000       ; 67 - 60
        DC.B    %00000000       ; 6F - 68
        DC.B    %00000000       ; 77 - 70
KMLRepeatable:
        DC.B    %11111111       ; 7\ 6& 5% 4$ 3 2" 1! `~  07 - 00
        DC.B    %00101111       ; 0N NL \| '` ? 0= 9) 8(  0F - 08
        DC.B    %11111111       ; tT dD cC zZ wW hH qQ xX  17 - 10
        DC.B    %00001111       ; 3 2 1 NL +* jJ pP bB  1F - 18
        DC.B    %11111111       ; nN rR lL oO eE aA iI uU  27 - 20
        DC.B    %00001111       ; 6 5 4 NL #' vF fF sS  2F - 28
        DC.B    %11111111       ; mM gG kK yY    <>  37 - 30
        DC.B    %00000111       ; 9  8  7  . NL -_ .: ,;  3F - 38
KMHRepeatable:
        DC.B    %01000111       ; 47 - 40  NL Del Esc Ret Ent Tab BS SPC
        DC.B    %11110011       ; 4F - 48  CBack CFor CDown CUp F11 NumPad- PDown PUp
        DC.B    %00000000       ; 57 - 50  F8-F1
        DC.B    %00000000       ; 5F - 58  Help + * / ]} [{ F10 F9 ;; NumPad
        DC.B    %00000000       ; 67 - 60  RAmiga LAmiga RAlt LAlt CtrlCaps RShift LShift
        DC.B    %00000000       ; 6F - 68  F12 Pause/Break NL NL NL MMB RMB LMB
        DC.B    %00000000       ; 77 - 70  NL NL NL NL NL NL End Home
KMLowMapType:
        DC.B    KCF_DEAD+KCF_SHIFT+KCF_ALT ;            $00
        DC.B    KCF_SHIFT+KCF_ALT       ; 1!
        DC.B    KCF_SHIFT+KCF_ALT       ; 2"
        DC.B    KCF_SHIFT+KCF_ALT       ; 3s
        DC.B    KCF_SHIFT+KCF_ALT       ; 4$
        DC.B    KCF_SHIFT+KCF_ALT       ; 5%
        DC.B    KC_VANILLA              ; 6&
        DC.B    KCF_SHIFT+KCF_ALT       ; 7/
        DC.B    KCF_SHIFT+KCF_ALT       ; 8(            $08
        DC.B    KCF_SHIFT+KCF_ALT       ; 9)
        DC.B    KCF_SHIFT+KCF_ALT       ; 0=
        DC.B    KCF_SHIFT+KCF_ALT       ; ?
        DC.B    KCF_DEAD+KC_VANILLA     ; '`
        DC.B    KC_VANILLA              ; \|
        DC.B    KCF_NOP                 ; NL
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad 0
        DC.B    KC_VANILLA              ; xX            $10
        DC.B    KC_VANILLA              ; qQ
        DC.B    KC_VANILLA              ; hH
        DC.B    KC_VANILLA              ; wW
        DC.B    KCF_DEAD+KC_VANILLA     ; zZ
        DC.B    KCF_DEAD+KC_VANILLA     ; cC
        DC.B    KC_VANILLA              ; dD
        DC.B    KCF_DEAD+KC_VANILLA     ; tT
        DC.B    KC_VANILLA              ; bB            $18
        DC.B    KC_VANILLA              ; pP
        DC.B    KC_VANILLA              ; jJ
        DC.B    KC_VANILLA              ; +*
        DC.B    KCF_NOP                 ; NL
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad 1
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad 2
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad 3
        DC.B    KCF_DEAD+KC_VANILLA     ; uU            $20
        DC.B    KCF_DEAD+KC_VANILLA     ; iI
        DC.B    KCF_DEAD+KC_VANILLA     ; aA
        DC.B    KCF_DEAD+KC_VANILLA     ; eE
        DC.B    KCF_DEAD+KC_VANILLA     ; oO
        DC.B    KCF_DEAD+KC_VANILLA     ; lL
        DC.B    KC_VANILLA              ; rR
        DC.B    KCF_DEAD+KC_VANILLA     ; nN
        DC.B    KCF_DEAD+KC_VANILLA     ; sS            $28
        DC.B    KCF_DEAD+KC_VANILLA     ; fF
        DC.B    KC_VANILLA              ; vV
        DC.B    KC_VANILLA              ; #^
        DC.B    KCF_NOP                 ; NL
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad 4
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad 5
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad 6
        DC.B    KCF_SHIFT+KCF_ALT       ; <>            $30
        DC.B    KCF_SHIFT+KCF_ALT       ; 
        DC.B    KCF_SHIFT+KCF_ALT       ; 
        DC.B    KCF_DEAD+KCF_SHIFT+KCF_ALT ; 
        DC.B    KCF_DEAD+KC_VANILLA     ; yY
        DC.B    KCF_DEAD+KC_VANILLA     ; kK
        DC.B    KCF_DEAD+KC_VANILLA     ; gG
        DC.B    KCF_DEAD+KC_VANILLA     ; mM
        DC.B    KCF_SHIFT+KCF_ALT       ; ,;            $38
        DC.B    KCF_SHIFT+KCF_ALT       ; .:
        DC.B    KCF_DEAD+KC_VANILLA     ; -_
        DC.B    KCF_NOP                 ; NL
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad .
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad 7
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad 8
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad 9
KMHighMapType:
        DC.B    KCF_DEAD+KCF_ALT        ; SPACE         $40  -> dead+shift
        DC.B    KC_NOQUAL               ; BACKSPACE
        DC.B    KCF_STRING+KCF_SHIFT    ; TAB
        DC.B    KC_NOQUAL               ; ENTER
        DC.B    KCF_CONTROL             ; RETURN
        DC.B    KCF_ALT                 ; ESCAPE
        DC.B    KC_NOQUAL               ; DELETE
        DC.B    KCF_STRING+KCF_SHIFT    ; INSERT
        DC.B    KCF_STRING+KCF_SHIFT    ; PAGE UP       $48
        DC.B    KCF_STRING+KCF_SHIFT    ; PAGE DOWN
        DC.B    KCF_SHIFT+KCF_ALT       ; Numpad -
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 11
        DC.B    KCF_STRING+KCF_SHIFT    ; CURSOR UP
        DC.B    KCF_STRING+KCF_SHIFT    ; CURSOR DOWN
        DC.B    KCF_STRING+KCF_SHIFT    ; CURSOR FORWARD
        DC.B    KCF_STRING+KCF_SHIFT    ; CURSOR BACKWARD
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 1        $50
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 2
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 3
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 4
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 5
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 6
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 7
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 8
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 9        $58
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 10
        DC.B    KC_VANILLA              ; Numeric Pad [{
        DC.B    KC_VANILLA              ; Numeric Pad ]}
        DC.B    KCF_SHIFT+KCF_ALT       ; Numeric Pad /
        DC.B    KCF_SHIFT+KCF_ALT       ; Numeric Pad *
        DC.B    KCF_SHIFT+KCF_ALT       ; Numeric Pad +
        DC.B    KCF_STRING              ; Help
        DC.B    KCF_NOP                 ; Left Shift    $60
        DC.B    KCF_NOP                 ; Right Shift
        DC.B    KCF_NOP                 ; Caps Lock
        DC.B    KCF_NOP                 ; Control
        DC.B    KCF_NOP                 ; Left Alt
        DC.B    KCF_NOP                 ; Right Alt
        DC.B    KCF_NOP                 ; Left Amiga
        DC.B    KCF_NOP                 ; Right Amiga
        DC.B    KCF_NOP                 ; Left Mouse Button $68
        DC.B    KCF_NOP                 ; Right Mouse Button
        DC.B    KCF_NOP                 ; Middle Mouse Button
        DC.B    KCF_NOP
        DC.B    KCF_NOP
        DC.B    KCF_NOP
        DC.B    KCF_STRING+KCF_SHIFT    ; PAUSE/BREAK
        DC.B    KCF_STRING+KCF_SHIFT    ; FKEY 12
        DC.B    KCF_STRING+KCF_SHIFT    ; HOME          $70
        DC.B    KCF_STRING+KCF_SHIFT    ; END
        DC.B    KCF_NOP
        DC.B    KCF_NOP
        DC.B    KCF_NOP
        DC.B    KCF_NOP
        DC.B    KCF_NOP
        DC.B    KCF_NOP

KMLowMap:
        DC.L    key00           ; `, ~, dead `, dead~                  $00
        DC.B    $B9,$A1,'!','1' ; 1, !, inverted !, super 1
        DC.B    $B2,'@','"','2' ; 2, ", @, super 2
        DC.B    $B3,'#',$A7,'3' ; 3, section, #, super 3
        DC.B    $A2,$B0,'$','4' ; 4, $, degree, cents
        DC.B    '%',$BC,'%','5' ; 5, %, 1/4, %
        DC.B    '^',$BD,'&','6' ; 6, &, 1/2, ^
        DC.B    '&',$BE,'/','7' ; 7, /, 3/4, &
        DC.B    '*',$B7,'(','8' ; 8, (, bullet, *                       $08
        DC.B    '(',$AB,')','9' ; 9, ), <<, (
        DC.B    ')',$BB,'=','0' ; 0, =, >>, )
        DC.B    $BF,$B8,'?',$DF ; sharp s, ?, cedilla, inverted ?
        DC.L    key0C           ; dead ', dead `, =, +
        DC.B    $A6,$5C,'|',$5C ; \, |, \, broken |
        DC.L    0               ; NOP
        DC.B    '0',$B0,$B0,'0' ; numeric pad 0 (0, degree, degree, 0)
        DC.B    $F7,$D7,'X','x' ; x, X, times, divide                   $10
        DC.B    $AC,$B1,'Q','q' ; q, Q, +/-, not
        DC.B    $AF,$BD,'H','h' ; h, H, 1/2, overbar
        DC.B    $B0,$B0,'W','w' ; w, W, dot, dot
        DC.L    key14           ; z, Z, dead `
        DC.L    key15           ; y, Y, IMS, Yen
        DC.B    $D0,$F0,'D','d' ; d, D, bar d, bar D
        DC.L    key17           ; t, T, thorn, THORN
        DC.B    $BF,$B8,'B','b' ; b, B, cedilla, inverted ?             $18
        DC.B    $B6,$B6,'P','p' ; p, P, paragraph, paragraph
        DC.B    '{','[','J','j' ; j, J, [, {
        DC.B    '}',']','*','+' ; +, *, ], }
        DC.L    0               ; NOP
        DC.B    '1',$B9,$B9,'1' ; numeric pad 1 (1, super 1, super 1, 1)
        DC.B    '2',$B2,$B2,'2' ; numeric pad 2 (2, super 2, super 2, 2)
        DC.B    '3',$B3,$B3,'3' ; numeric pad 3 (3, super 3, super 3, 3)
        DC.L    key20           ; u, U, micro, micro                    $20
        DC.L    key21           ; i, I, inverted !, broken |
        DC.L    key22           ; a, A, female ordinal, female ordinal
        DC.L    key23           ; e, E, male ordinal, male ordinal
        DC.L    key24           ; o, O, aa (=dot a), AA (=dot A)
        DC.L    key25           ; l, L, pound, pound
        DC.B    $AE,$AE,'R','r' ; r, R, (r), (r)
        DC.L    key27           ; n, N, (c), (c)
        DC.L    key28           ; s, S, section, male ordinal           $28
        DC.L    key29           ; f, F, female ordinal, female ordinal
        DC.B    '"',$27,'V','v' ; v, V, ', "
        DC.B    '^','#','^','#' ; #, ^, #, ^
        DC.L    0               ; NOP
        DC.B    '4',$BC,$BC,'4' ; numeric pad 4 (4, 1/4, 1/4, 4)
        DC.B    '5',$BD,$BD,'5' ; numeric pad 5 (5, 1/4, 1/4, 5)
        DC.B    '6',$BE,$BE,'6' ; numeric pad 6 (5, 1/4, 1/4, 6)
        DC.B    $BB,$AB,'>','<' ; <, >, <<, >>                          $30
        DC.B    $D8,$F8,$D6,$F6 ; umlaut o, umlaut O, slash o, slash O
        DC.B    $C6,$E6,$C4,$E4 ; umlaut a, umlaut A, ae, AE
        DC.L    key33           ; u umlaut, U umlaut, dead '
        DC.L    key34           ; c, C, c cedilla, C cedilla
        DC.L    key35           ; k, K, dead ^
        DC.L    key36           ; g, G, dead ~
        DC.L    key37           ; m, M, dead "
        DC.B    '<',',',';',',' ; ,, ;, ,, <                            $38
        DC.B    '>',$B7,':','.' ; ., :, , >
        DC.L    key3A           ; -, _, SHY, negation, et al
        DC.L    0               ; NOP
        DC.B    ".","","","." ; numeric pad . (.)
        DC.B    '7',$A0,$A0,'7' ; numeric pad 7 (7, NBS, NBS, 7)
        DC.B    '8',$AD,$AD,'8' ; numeric pad 8 (8, SHY, SHY, 8)
        DC.B    '9',$A6,$A6,'9' ; numeric pad 9 (9, broken bar, broken bar, 9)
KMHighMap:
        DC.L    key40           ;                                       $40
        DC.B    0,0,0,$08
        DC.L    key42
        DC.B    0,0,0,$0D
        DC.B    0,0,$0A,$0D
        DC.B    0,0,$9B,$1B
        DC.B    0,0,0,$7F
        DC.L    key47
        DC.L    key48           ;                                       $48
        DC.L    key49
        DC.B    '-',$AC,$AC,'-' ; numeric pad -
        DC.L    key4B
        DC.L    key4C
        DC.L    key4D
        DC.L    key4E
        DC.L    key4F
        DC.L    key50           ;                                       $50
        DC.L    key51
        DC.L    key52
        DC.L    key53
        DC.L    key54
        DC.L    key55
        DC.L    key56
        DC.L    key57
        DC.L    key58           ;                                       $58
        DC.L    key59
        DC.B    '[','{','{','[' ; numeric pad [, {
        DC.B    ']','}','}',']' ; numeric pad ], }
        DC.B    '/',$F7,$F7,'/' ; numeric pad /
        DC.B    '*',$D7,$D7,'*' ; numeric pad *
        DC.B    '+',$B1,$B1,'+' ; numeric pad +
        DC.L    key5F
        DC.L    0               ;                                       $60
        DC.L    0
        DC.L    0
        DC.L    0
        DC.L    0
        DC.L    0
        DC.L    0
        DC.L    0
        DC.L    0               ;                                       $68
        DC.L    0
        DC.L    0
        DC.L    0
        DC.L    0
        DC.L    0
        DC.L    key6E
        DC.L    key6F
        DC.L    key70           ;                                       $70
        DC.L    key71
        DC.L    0
        DC.L    0
        DC.L    0
        DC.L    0
        DC.L    0
        DC.L    0
;
;------ possible dead keys ---------------------------
;
key00:
        DC.B    0,"`",0,"~"
        DC.B    DPF_DEAD,2+(6<<DP_2DFACSHIFT)   ; dead `
        DC.B    DPF_DEAD,4                      ; dead ~
key0C:
        DC.B    DPF_DEAD,1+(6<<DP_2DFACSHIFT)   ; dead '
        DC.B    DPF_DEAD,2+(6<<DP_2DFACSHIFT)   ; dead `
        DC.B    DPF_DEAD,4                      ; dead ~
        DC.B    DPF_DEAD,3                      ; dead ^
        DC.B    0,"",0,"`"                     ; , `
        DC.B    0,'=',0,'+'                     ; =, +
key33:
        DC.B    0,$FC,0,$DC                     ; u umlaut, U umlaut
        DC.B    DPF_DEAD,1+(6<<DP_2DFACSHIFT)   ; dead '
        DC.B    DPF_DEAD,1+(6<<DP_2DFACSHIFT)   ; dead '
;       DC.B    0,$1B,0,$9B,0,$1B,0,$9B         ; control translation   **??**
key14:
        DC.B    0,'z',0,'Z'                     ; z, Z
        DC.B    0,$BF                           ; inverted ?
        DC.B    DPF_DEAD,2+(6<<DP_2DFACSHIFT)   ; dead `
        DC.B    0,$1A,0,$1A,0,$9A,0,$9A         ; control translation
key35:
        DC.B    0,'k',0,'K'                     ; k, K
        DC.B    0,$BE,     DPF_DEAD,3           ; 3/4, dead ^
        DC.B    0,$0B,0,$0B,0,$8B,0,$8B         ; control translation
key36:
        DC.B    0,'g',0,'G'                     ; g, G
        DC.B    DPF_DEAD,4,DPF_DEAD,4           ; dead ~, dead ~
        DC.B    0,$07,0,$07,0,$87,0,$87         ; control translation
key37:
        DC.B    0,'m',0,'M'                     ; m, M
        DC.B    DPF_DEAD,5,DPF_DEAD,5           ; dead ", dead "
        DC.B    0,$0D,0,$0D,0,$8D,0,$8D         ; control translation

key3A:  ; "-" (Alpha-Num)
        DC.B    0,'-',0,'_'                      ; minus, underscore
        DC.B    0,$AD,0,$AF                      ; Soft-Hyphen, overscore
        DC.B    0,$1F,0,$1F                      ; ctrl-underscore
        DC.B    0,$8F,0,$8F                      ; ctrl-overstrike
;
;------ deadable keys (modified by dead keys) ----------------------
;
key15:  DC.B    DPF_MOD,key15u-key15, 0, "C"
        DC.B    0,$E7,0,$C7
        DC.B    0,$03,0,$03,0,$83,0,$83 ; control translation
key15u:
        DC.B    'c',$9C,'c','c','c','c'
        DC.B    $9C,$9C,$9C,$9C,$9C,$9C
        DC.B    'c','c','c','c','c','c'
key20:                ; u, U, micro, micro
        DC.B    DPF_MOD,key20u-key20,DPF_MOD,key20s-key20
        DC.B    0,$B5,0,$B5
        DC.B    0,$15,0,$15,0,$95,0,$95 ; control translation
key20u:
        DC.B    'u',$FA,$F9,$FB,$FC,$FC
        DC.B    $FA,$FA,$FB,$FA,$FA,$FA
        DC.B    $F9,$FB,$F9,$F9,$F9,$F9
key20s:
        DC.B    'U',$DA,$D9,$DB,$DC,$DC
        DC.B    $DA,$DA,$DB,$DA,$DA,$DA
        DC.B    $D9,$DB,$D9,$D9,$D9,$D9

key21:                  ; i, I, inverted !, broken |
        DC.B    DPF_MOD,key21u-key21,DPF_MOD,key21s-key21
        DC.B    0,$A1,0,$A6
        DC.B    0,$09,0,$09,0,$89,0,$89 ; control translation
key21u:
        DC.B    'i',$ED,$EC,$EE,$EF,$EF
        DC.B    $ED,$ED,$EE,$ED,$ED,$ED
        DC.B    $EC,$EE,$EC,$EC,$EC,$EC
key21s:
        DC.B    'I',$CD,$CC,$CE,$CF,$CF
        DC.B    $CD,$CD,$CE,$CD,$CD,$CD
        DC.B    $CC,$CE,$CC,$CC,$CC,$CC

key22:              ; a, A, female ordinal, female ordinal
        DC.B    DPF_MOD,key22u-key22,DPF_MOD,key22s-key22
        DC.B    0,$AA,0,$AA
        DC.B    0,$01,0,$01,0,$81,0,$81 ; control translation
key22u:
        DC.B    'a',$E1,$E0,$E2,$E3,$E4
        DC.B    $E1,$E1,$E2,$E1,$E1,$E1 ; most recent is '
        DC.B    $E0,$E2,$E0,$E0,$E0,$E0 ; most recent is `
key22s:
        DC.B    'A',$C1,$C0,$C2,$C3,$C4
        DC.B    $C1,$C1,$C2,$C1,$C1,$C1 ; most recent is '
        DC.B    $C0,$C2,$C0,$C0,$C0,$C0 ; most recent is `

key23:              ; e, E, male or'inal, male ordinal
        DC.B    DPF_MOD,key23u-key23,DPF_MOD,key23s-key23
        DC.B    0,$BA,0,$BA
        DC.B    0,$05,0,$05,0,$85,0,$85 ; control translation
key23u:
        DC.B    'e',$E9,$E8,$EA,$EB,$EB
        DC.B    $E9,$E9,$EA,$E9,$E9,$E9
        DC.B    $E8,$EA,$E8,$E8,$E8,$E8
key23s:
        DC.B    'E',$C9,$C8,$CA,$CB,$CB
        DC.B    $C9,$C9,$CA,$C9,$C9,$C9
        DC.B    $C8,$CA,$C8,$C8,$C8,$C8

key24:              ; o, O, aa (=dot a), AA (=dot A)
        DC.B    DPF_MOD,key24u-key24,DPF_MOD,key24s-key24
        DC.B    0,$E5,0,$c5
        DC.B    0,$0F,0,$0F,0,$8F,0,$8F ; control translation
key24u:
        DC.B    'o',$F3,$F2,$F4,$F5,$F6
        DC.B    $F3,$F3,$F4,$F3,$F3,$F3
        DC.B    $F2,$F4,$F2,$F2,$F2,$F2
key24s:
        DC.B    'O',$D3,$D2,$D4,$D5,$D6
        DC.B    $D3,$D3,$D4,$D3,$D3,$D3
        DC.B    $D2,$D4,$D2,$D2,$D2,$D2

key27:              ; n, N, (c), (c)
        DC.B    DPF_MOD,key27u-key27,DPF_MOD,key27s-key27
        DC.B    0,$A9,0,$A9
        DC.B    0,$0E,0,$0E,0,$8E,0,$8E ; control translation
key27u:
        DC.B    'n','n','n','n',$F1,'n'
        DC.B    'n','n','n','n','n','n'
        DC.B    'n','n','n','n','n','n'
key27s:
        DC.B    'N','N','N','N',$D1,'N'
        DC.B    'N','N','N','N','N','N'
        DC.B    'N','N','N','N','N','N'

key40:                  ; space,NBSP, and accents
        DC.B    DPF_MOD,key40d-key40,   0,$A0
key40d:
        DC.B    ' ',$B4,'`','^','~',$A8
        DC.B    $B4,'^',$B4,$B4,$B4,$B4
        DC.B    '`','`','^','`','`','`'
;
;------ keys for "igaturen" -------------
;
key17:  DC.B    DPF_MOD,key17u-key17, 0, "T"
        DC.B    0,$FE,0,$DE
        DC.B    0,$14,0,$14,0,$94,0,$94 ; control translation
key17u:
        DC.B    't',$8F,$9F,'t','t','t'
        DC.B    $8F,$8F,$8F,$8F,$8F,$8F
        DC.B    $9F,$9F,$9F,$9F,$9F,$9F

key25:  DC.B    DPF_MOD,key25u-key25, 0, "L"
        DC.B    0,$A3,0,$A3
        DC.B    0,$0C,0,$0C,0,$8C,0,$8C ; control translation
key25u:
        DC.B    'l',$90,$8D,'l','l','l'
        DC.B    $90,$90,$90,$90,$90,$90
        DC.B    $8D,$8D,$8D,$8D,$8D,$8D

key28:  DC.B    DPF_MOD,key28u-key28, 0, "S"
        DC.B    0,$FF,0,$BA
        DC.B    0,$13,0,$13,0,$93,0,$93 ; control translation
key28u:
        DC.B    's',$9E,$9D,'s','s','s'
        DC.B    $9E,$9E,$9E,$9E,$9E,$9E
        DC.B    $9D,$9D,$9D,$9D,$9D,$9D

key29:  DC.B    DPF_MOD,key29u-key29, 0, "F"
        DC.B    0,$AA,0,$AA
        DC.B    0,$06,0,$06,0,$84,0,$86 ; control translation
key29u:
        DC.B    'f',$8C,$8E,'f','f','f'
        DC.B    $8C,$8C,$8C,$8C,$8C,$8C
        DC.B    $8E,$8E,$8E,$8E,$8E,$8E

key34:              ; y, Y, IMS, Yen
        DC.B    DPF_MOD,key34u-key34,DPF_MOD,key34s-key34
        DC.B    0,$A4,0,$A5
        DC.B    0,$19,0,$19,0,$99,0,$99 ; control translation
key34u:
        DC.B    'y',$FD,'y','y',$FF,$FF
        DC.B    $FD,$FD,$FD,$FD,$FD,$FD
        DC.B    'y','y','y','y','y','y'
key34s:
        DC.B    'Y',$DD,'Y','Y','Y','Y'
        DC.B    $DD,$DD,$DD,$DD,$DD,$DD
        DC.B    'Y','Y','Y','Y','Y','Y'

;
;------ string keys ----------------------
;
key42:
        DC.B    key42ue-key42us,key42us-key42
        DC.B    key42se-key42ss,key42ss-key42
key42us:
        DC.B    $09
key42ue:
key42ss:
        DC.B    $9B,'Z'
key42se:
key47:  ; Insert
        DC.B    key47ue-key47us,key47us-key47
        DC.B    key47se-key47ss,key47ss-key47
key47us:
        DC.B    $9B,'40~'
key47ue:
key47ss:
        DC.B    $9B,'50~'
key47se:
key48:  ; Page Up
        DC.B    key48ue-key48us,key48us-key48
        DC.B    key48se-key48ss,key48ss-key48
key48us:
        DC.B    $9B,'41~'
key48ue:
key48ss:
        DC.B    $9B,'51~'
key48se:
key49:  ; Page Down
        DC.B    key49ue-key49us,key49us-key49
        DC.B    key49se-key49ss,key49ss-key49
key49us:
        DC.B    $9B,'42~'
key49ue:
key49ss:
        DC.B    $9B,'52~'
key49se:
key4B:  ; F11
        DC.B    key4Bue-key4Bus,key4Bus-key4B
        DC.B    key4Bse-key4Bss,key4Bss-key4B
key4Bus:
        DC.B    $9B,'20~'
key4Bue:
key4Bss:
        DC.B    $9B,'30~'
key4Bse:
key4C:
        DC.B    key4Cue-key4Cus,key4Cus-key4C
        DC.B    key4Cse-key4Css,key4Css-key4C
key4Cus:
        DC.B    $9B,'A'
key4Cue:
key4Css:
        DC.B    $9B,'T'
key4Cse:
key4D:
        DC.B    key4Due-key4Dus,key4Dus-key4D
        DC.B    key4Dse-key4Dss,key4Dss-key4D
key4Dus:
        DC.B    $9B,'B'
key4Due:
key4Dss:
        DC.B    $9B,'S'
key4Dse:
key4E:
        DC.B    key4Eue-key4Eus,key4Eus-key4E
        DC.B    key4Ese-key4Ess,key4Ess-key4E
key4Eus:
        DC.B    $9B,'C'
key4Eue:
key4Ess:
        DC.B    $9B,' ','@'
key4Ese:
key4F:
        DC.B    key4Fue-key4Fus,key4Fus-key4F
        DC.B    key4Fse-key4Fss,key4Fss-key4F
key4Fus:
        DC.B    $9B,'D'
key4Fue:
key4Fss:
        DC.B    $9B,' ','A'
key4Fse:
key50:
        DC.B    key50ue-key50us,key50us-key50
        DC.B    key50se-key50ss,key50ss-key50
key50us:
        DC.B    $9B,'0~'
key50ue:
key50ss:
        DC.B    $9B,'10~'
key50se:
key51:
        DC.B    key51ue-key51us,key51us-key51
        DC.B    key51se-key51ss,key51ss-key51
key51us:
        DC.B    $9B,'1~'
key51ue:
key51ss:
        DC.B    $9B,'11~'
key51se:
key52:
        DC.B    key52ue-key52us,key52us-key52
        DC.B    key52se-key52ss,key52ss-key52
key52us:
        DC.B    $9B,'2~'
key52ue:
key52ss:
        DC.B    $9B,'12~'
key52se:
key53:
        DC.B    key53ue-key53us,key53us-key53
        DC.B    key53se-key53ss,key53ss-key53
key53us:
        DC.B    $9B,'3~'
key53ue:
key53ss:
        DC.B    $9B,'13~'
key53se:
key54:
        DC.B    key54ue-key54us,key54us-key54
        DC.B    key54se-key54ss,key54ss-key54
key54us:
        DC.B    $9B,'4~'
key54ue:
key54ss:
        DC.B    $9B,'14~'
key54se:
key55:
        DC.B    key55ue-key55us,key55us-key55
        DC.B    key55se-key55ss,key55ss-key55
key55us:
        DC.B    $9B,'5~'
key55ue:
key55ss:
        DC.B    $9B,'15~'
key55se:
key56:
        DC.B    key56ue-key56us,key56us-key56
        DC.B    key56se-key56ss,key56ss-key56
key56us:
        DC.B    $9B,'6~'
key56ue:
key56ss:
        DC.B    $9B,'16~'
key56se:
key57:
        DC.B    key57ue-key57us,key57us-key57
        DC.B    key57se-key57ss,key57ss-key57
key57us:
        DC.B    $9B,'7~'
key57ue:
key57ss:
        DC.B    $9B,'17~'
key57se:
key58:
        DC.B    key58ue-key58us,key58us-key58
        DC.B    key58se-key58ss,key58ss-key58
key58us:
        DC.B    $9B,'8~'
key58ue:
key58ss:
        DC.B    $9B,'18~'
key58se:
key59:
        DC.B    key59ue-key59us,key59us-key59
        DC.B    key59se-key59ss,key59ss-key59
key59us:
        DC.B    $9B,'9~'
key59ue:
key59ss:
        DC.B    $9B,'19~'
key59se:
key5F:
        DC.B    key5Fe-key5Fs,key5Fs-key5F
key5Fs:
        DC.B    $9B,'?~'
key5Fe:
key6E:  ; Pause/Break
        DC.B    key6Eue-key6Eus,key6Eus-key6E
        DC.B    key6Ese-key6Ess,key6Ess-key6E
key6Eus:
        DC.B    $9B,'43~'
key6Eue:
key6Ess:
        DC.B    $9B,'53~'
key6Ese:
key6F:  ; F12
        DC.B    key6Fue-key6Fus,key6Fus-key6F
        DC.B    key6Fse-key6Fss,key6Fss-key6F
key6Fus:
        DC.B    $9B,'21~'
key6Fue:
key6Fss:
        DC.B    $9B,'31~'
key6Fse:
key70:  ; Home
        DC.B    key70ue-key70us,key70us-key70
        DC.B    key70se-key70ss,key70ss-key70
key70us:
        DC.B    $9B,'44~'
key70ue:
key70ss:
        DC.B    $9B,'54~'
key70se:

key71:  ; End
        DC.B    key71ue-key71us,key71us-key71
        DC.B    key71se-key71ss,key71ss-key71
key71us:
        DC.B    $9B,'45~'
key71ue:
key71ss:
        DC.B    $9B,'55~'
key71se:

KMName:

        DC.B    'd-ergo',0

kmEnd
        END
